CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
105 lines
3.2 KiB
C++
105 lines
3.2 KiB
C++
/*
|
|
* Copyright (c) Advanced Micro Devices, Inc., or its affiliates.
|
|
*
|
|
* SPDX-License-Identifier: MIT
|
|
*/
|
|
|
|
#include <hip_test_common.hh>
|
|
|
|
/*
|
|
* Square each element in the array A and write to array C.
|
|
*/
|
|
template <typename T> static __global__ void vector_square_generic(T* C_d, const T* A_d, size_t N) {
|
|
size_t offset = (blockIdx.x * blockDim.x + threadIdx.x);
|
|
size_t stride = blockDim.x * gridDim.x;
|
|
|
|
for (size_t i = offset; i < N; i += stride) {
|
|
C_d[i] = A_d[i] * A_d[i];
|
|
}
|
|
}
|
|
|
|
#ifdef GENERIC_COMPRESSED
|
|
HIP_TEST_CASE(Unit_test_generic_target_in_compressed_fatbin) {
|
|
#else
|
|
HIP_TEST_CASE(Unit_test_generic_target_in_regular_fatbin) {
|
|
#endif
|
|
if (!isGenericTargetSupported()) {
|
|
HIP_SKIP_TEST("generic target is not supported on this device.");
|
|
}
|
|
float *A_d, *C_d;
|
|
float *A_h, *C_h;
|
|
size_t N = 1000000;
|
|
size_t Nbytes = N * sizeof(float);
|
|
static int device = 0;
|
|
HIP_CHECK(hipSetDevice(device));
|
|
hipDeviceProp_t props;
|
|
HIP_CHECK(hipGetDeviceProperties(&props, device /*deviceID*/));
|
|
printf("info: running on device %s\n", props.name);
|
|
#ifdef __HIP_PLATFORM_AMD__
|
|
printf("info: architecture on AMD GPU device is: %s\n", props.gcnArchName);
|
|
// check the scope of supportted types
|
|
#endif
|
|
printf("info: allocate host mem (%6.2f MB)\n", 2 * Nbytes / 1024.0 / 1024.0);
|
|
A_h = (float*)malloc(Nbytes);
|
|
HIP_CHECK(A_h == 0 ? hipErrorOutOfMemory : hipSuccess);
|
|
C_h = (float*)malloc(Nbytes);
|
|
HIP_CHECK(C_h == 0 ? hipErrorOutOfMemory : hipSuccess);
|
|
// Fill with Phi + i
|
|
for (size_t i = 0; i < N; i++) {
|
|
A_h[i] = 1.618f + i;
|
|
}
|
|
printf("info: allocate device mem (%6.2f MB)\n", 2 * Nbytes / 1024.0 / 1024.0);
|
|
HIP_CHECK(hipMalloc(&A_d, Nbytes));
|
|
HIP_CHECK(hipMalloc(&C_d, Nbytes));
|
|
|
|
printf("info: copy Host2Device\n");
|
|
HIP_CHECK(hipMemcpy(A_d, A_h, Nbytes, hipMemcpyHostToDevice));
|
|
|
|
const unsigned blocks = 512;
|
|
const unsigned threadsPerBlock = 256;
|
|
|
|
printf("info: launch 'vector_square' kernel\n");
|
|
hipLaunchKernelGGL(vector_square_generic, dim3(blocks), dim3(threadsPerBlock), 0, 0, C_d, A_d, N);
|
|
|
|
printf("info: copy Device2Host\n");
|
|
HIP_CHECK(hipMemcpy(C_h, C_d, Nbytes, hipMemcpyDeviceToHost));
|
|
HIP_CHECK(hipDeviceSynchronize());
|
|
|
|
printf("info: check result\n");
|
|
for (size_t i = 0; i < N; i++) {
|
|
if (C_h[i] != A_h[i] * A_h[i]) {
|
|
HIP_CHECK(hipErrorUnknown);
|
|
}
|
|
}
|
|
HIP_CHECK(hipFree(A_d));
|
|
HIP_CHECK(hipFree(C_d));
|
|
free(A_h);
|
|
free(C_h);
|
|
printf("PASSED!\n");
|
|
REQUIRE(true);
|
|
}
|
|
|
|
#ifndef NO_GENERIC_TARGET_ONLY_TEST
|
|
#ifdef GENERIC_COMPRESSED
|
|
HIP_TEST_CASE(Unit_test_generic_target_only_in_compressed_fatbin) {
|
|
#ifdef __linux__
|
|
const char* cmd =
|
|
"chmod u+x ./hipSquareGenericTargetOnlyCompressed && ./hipSquareGenericTargetOnlyCompressed";
|
|
#else
|
|
const char* cmd = "hipSquareGenericTargetOnlyCompressed.exe";
|
|
#endif
|
|
#else // else GENERIC_COMPRESSED
|
|
HIP_TEST_CASE(Unit_test_generic_target_only_in_regular_fatbin) {
|
|
#ifdef __linux__
|
|
const char* cmd = "chmod u+x ./hipSquareGenericTargetOnly && ./hipSquareGenericTargetOnly";
|
|
#else
|
|
const char* cmd = "hipSquareGenericTargetOnly.exe";
|
|
#endif
|
|
#endif // GENERIC_COMPRESSED
|
|
|
|
printf("Run %s\n", cmd);
|
|
REQUIRE(std::system(cmd) == 0);
|
|
printf("PASSED!\n");
|
|
}
|
|
#endif // NO_GENERIC_TARGET_ONLY_TEST
|